@@ -65,7 +65,7 @@ char * replace_word();
 
 typedef unsigned int ID_TYPE; 
 
-#if 0  /* commented on jslib.c as well (strange)
+#if 0  /* commented on jslib.c as well (strange) */
 
 ID_TYPE word_id(char *word, char *feats, int *status);
 /* this function gives a unique identifier for a given word */
